==> haskell-jose-0.7.0.0-30-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-jose.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: jose
version: 0.7.0.0
id: jose-0.7.0.0-G7qTElArWXSC6LhAwzuhss
key: jose-0.7.0.0-G7qTElArWXSC6LhAwzuhss
license: Apache-2.0
copyright: Copyright (C) 2013, 2014, 2015, 2016, 2017  Fraser Tweedale
maintainer: frase@frase.id.au
author: Fraser Tweedale
homepage: https://github.com/frasertweedale/hs-jose
synopsis: Javascript Object Signing and Encryption and JSON Web Token library
description:
    .
    An implementation of the Javascript Object Signing and Encryption
    (JOSE) and JSON Web Token (JWT; RFC 7519) formats.
    .
    The JSON Web Signature (JWS; RFC 7515) implementation is complete.
    .
    EdDSA signatures (RFC 8037) are supported (Ed25519 only).
    .
    JWK Thumbprint (RFC 7638) is supported (requires /aeson/ >= 0.10).
    .
    JSON Web Encryption (JWE; RFC 7516) is not yet implemented.
    .
    The __ECDSA implementation is vulnerable to timing attacks__ and
    should only be used for verification.
category: Cryptography
abi: 0a6d4fb5a559aca8bda3ab8b4b9c9265
exposed: True
exposed-modules:
    Crypto.JOSE Crypto.JOSE.AESKW Crypto.JOSE.Compact Crypto.JOSE.Error
    Crypto.JOSE.Header Crypto.JOSE.JWA.JWE Crypto.JOSE.JWA.JWE.Alg
    Crypto.JOSE.JWA.JWK Crypto.JOSE.JWA.JWS Crypto.JOSE.JWE
    Crypto.JOSE.JWK Crypto.JOSE.JWK.Store Crypto.JOSE.JWS
    Crypto.JOSE.Types Crypto.JWT
hidden-modules: Crypto.JOSE.TH Crypto.JOSE.Types.Internal
                Crypto.JOSE.Types.Orphans
import-dirs: /usr/lib/ghc-8.4.3/site-local/jose-0.7.0.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/jose-0.7.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/jose-0.7.0.0
hs-libraries: HSjose-0.7.0.0-G7qTElArWXSC6LhAwzuhss
depends:
    base-4.11.1.0 attoparsec-0.13.2.2-3qGxeNYxa6yc3jTIgvDuQ
    base64-bytestring-1.0.0.1-4OCIe2BZn8jKI191JIXI37
    concise-0.1.0.1-59LWNqTKY7t9ax2HSHO29q containers-0.5.11.0
    cryptonite-0.25-90uxV0bWEYmfC6QouwM7s
    lens-4.16.1-Lbt16M482ky7VAhdoH5BdO
    memory-0.14.16-Hs1NDoAVjuC3IQmOlFTQpi
    monad-time-0.3.1.0-EBUQiIAH86L3Y0scTTbaUJ mtl-2.2.2
    template-haskell-2.13.0.0 safe-0.3.17-HEmZRpXGD3s2ywM3rHJ1ur
    aeson-1.3.1.1-TT45dpTFlI3IDS4gOrl3y
    unordered-containers-0.2.9.0-4xkK4TVeOzU5CT7vUnH40Y
    bytestring-0.10.8.2 text-1.2.3.0 time-1.8.0.2
    network-uri-2.6.1.0-AstEwZoXrlUJQq4VkxaVo9
    QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr
    quickcheck-instances-0.3.18-3NJ92IP9Zm6CkknPAnb0EX
    x509-1.7.3-GRsinSiGUa6INSt3zoND4f
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             attoparsec-0.13.2.2-3qGxeNYxa6yc3jTIgvDuQ=d12eb845c076ee59608410c1ed86a159
             base64-bytestring-1.0.0.1-4OCIe2BZn8jKI191JIXI37=6373b2ec1ae2585bcca6cddbee5d3e75
             concise-0.1.0.1-59LWNqTKY7t9ax2HSHO29q=ef70f1386bff5e3caa17dc14053aecdf
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             cryptonite-0.25-90uxV0bWEYmfC6QouwM7s=ab6703e009204c8918b02064ccbf4d84
             lens-4.16.1-Lbt16M482ky7VAhdoH5BdO=e1de6ba4869fc28b6d3f9faac9ec1cc8
             memory-0.14.16-Hs1NDoAVjuC3IQmOlFTQpi=463ac0313409de6dd760baee29e5aba2
             monad-time-0.3.1.0-EBUQiIAH86L3Y0scTTbaUJ=e679d0596312baf03ac502de1b40f77b
             mtl-2.2.2=3cf3b316ad8e985e039ee3b498a98253
             template-haskell-2.13.0.0=1ce4a454c5861830bbdedc46baa462f3
             safe-0.3.17-HEmZRpXGD3s2ywM3rHJ1ur=f24d7708a3245ecd805ff7d598d8872c
             aeson-1.3.1.1-TT45dpTFlI3IDS4gOrl3y=07d229e9fe1ca7309e20349a237239ed
             unordered-containers-0.2.9.0-4xkK4TVeOzU5CT7vUnH40Y=35805d13add6a65c87fb8fb413d93b58
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             time-1.8.0.2=976962cc6498b843f1efb5bef740838e
             network-uri-2.6.1.0-AstEwZoXrlUJQq4VkxaVo9=1c5b19d707f7ce4714ffa81cd536dbf4
             QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr=0b62adbb61d61aac8d449588192e831b
             quickcheck-instances-0.3.18-3NJ92IP9Zm6CkknPAnb0EX=c9695f540a5cb704f8fccab26513e8c0
             x509-1.7.3-GRsinSiGUa6INSt3zoND4f=669fdff1caa149166283901867f22cc9
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=2d4c17574909e037fa0256847c747647
haddock-interfaces: /usr/share/doc/haskell-jose/html/jose.haddock
haddock-html: /usr/share/doc/haskell-jose/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-jose-0.7.0.0-38-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-jose.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: jose
version: 0.7.0.0
id: jose-0.7.0.0-Fb9v0fjliOSYiihySIUeP
key: jose-0.7.0.0-Fb9v0fjliOSYiihySIUeP
license: Apache-2.0
copyright: Copyright (C) 2013, 2014, 2015, 2016, 2017  Fraser Tweedale
maintainer: frase@frase.id.au
author: Fraser Tweedale
homepage: https://github.com/frasertweedale/hs-jose
synopsis: Javascript Object Signing and Encryption and JSON Web Token library
description:
    .
    An implementation of the Javascript Object Signing and Encryption
    (JOSE) and JSON Web Token (JWT; RFC 7519) formats.
    .
    The JSON Web Signature (JWS; RFC 7515) implementation is complete.
    .
    EdDSA signatures (RFC 8037) are supported (Ed25519 only).
    .
    JWK Thumbprint (RFC 7638) is supported (requires /aeson/ >= 0.10).
    .
    JSON Web Encryption (JWE; RFC 7516) is not yet implemented.
    .
    The __ECDSA implementation is vulnerable to timing attacks__ and
    should only be used for verification.
category: Cryptography
abi: 2aeff6ea197e7117ce337356b0a78496
exposed: True
exposed-modules:
    Crypto.JOSE Crypto.JOSE.AESKW Crypto.JOSE.Compact Crypto.JOSE.Error
    Crypto.JOSE.Header Crypto.JOSE.JWA.JWE Crypto.JOSE.JWA.JWE.Alg
    Crypto.JOSE.JWA.JWK Crypto.JOSE.JWA.JWS Crypto.JOSE.JWE
    Crypto.JOSE.JWK Crypto.JOSE.JWK.Store Crypto.JOSE.JWS
    Crypto.JOSE.Types Crypto.JWT
hidden-modules: Crypto.JOSE.TH Crypto.JOSE.Types.Internal
                Crypto.JOSE.Types.Orphans
import-dirs: /usr/lib/ghc-8.4.3/site-local/jose-0.7.0.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/jose-0.7.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/jose-0.7.0.0
hs-libraries: HSjose-0.7.0.0-Fb9v0fjliOSYiihySIUeP
depends:
    base-4.11.1.0 attoparsec-0.13.2.2-3qGxeNYxa6yc3jTIgvDuQ
    base64-bytestring-1.0.0.1-4OCIe2BZn8jKI191JIXI37
    concise-0.1.0.1-4CZZLacJOJyKxiuY679EGP containers-0.5.11.0
    cryptonite-0.25-Ka20h0HuI7x3L9WMrwHuzr
    lens-4.17-46TWctpZkRBHUbD4jUgMJb
    memory-0.14.16-FrHKJ6EcQ5I95PPEhrgDqk
    monad-time-0.3.1.0-EBUQiIAH86L3Y0scTTbaUJ mtl-2.2.2
    template-haskell-2.13.0.0 safe-0.3.17-HEmZRpXGD3s2ywM3rHJ1ur
    aeson-1.3.1.1-7VLuHgXpUZXICjV9H4HLME
    unordered-containers-0.2.9.0-4xkK4TVeOzU5CT7vUnH40Y
    bytestring-0.10.8.2 text-1.2.3.0 time-1.8.0.2
    network-uri-2.6.1.0-AstEwZoXrlUJQq4VkxaVo9
    QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr
    quickcheck-instances-0.3.18-Hbks6NNQUX8gR7hBY25ga
    x509-1.7.3-30RX2XeTxE9KNrE2njE3sg
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             attoparsec-0.13.2.2-3qGxeNYxa6yc3jTIgvDuQ=d12eb845c076ee59608410c1ed86a159
             base64-bytestring-1.0.0.1-4OCIe2BZn8jKI191JIXI37=6373b2ec1ae2585bcca6cddbee5d3e75
             concise-0.1.0.1-4CZZLacJOJyKxiuY679EGP=10df2a2906d1844d19a7b6d8c14bc3d3
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             cryptonite-0.25-Ka20h0HuI7x3L9WMrwHuzr=049bf293d9c1bef7bdb45e8c7d818d0c
             lens-4.17-46TWctpZkRBHUbD4jUgMJb=63a83ba94cfecc6580687b8535602d48
             memory-0.14.16-FrHKJ6EcQ5I95PPEhrgDqk=23a2e2ee61129c4073d4aeb70df9c169
             monad-time-0.3.1.0-EBUQiIAH86L3Y0scTTbaUJ=e679d0596312baf03ac502de1b40f77b
             mtl-2.2.2=3cf3b316ad8e985e039ee3b498a98253
             template-haskell-2.13.0.0=1ce4a454c5861830bbdedc46baa462f3
             safe-0.3.17-HEmZRpXGD3s2ywM3rHJ1ur=f24d7708a3245ecd805ff7d598d8872c
             aeson-1.3.1.1-7VLuHgXpUZXICjV9H4HLME=7ee9b817f9a46427a0a72def7776ba94
             unordered-containers-0.2.9.0-4xkK4TVeOzU5CT7vUnH40Y=35805d13add6a65c87fb8fb413d93b58
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             time-1.8.0.2=976962cc6498b843f1efb5bef740838e
             network-uri-2.6.1.0-AstEwZoXrlUJQq4VkxaVo9=1c5b19d707f7ce4714ffa81cd536dbf4
             QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr=0b62adbb61d61aac8d449588192e831b
             quickcheck-instances-0.3.18-Hbks6NNQUX8gR7hBY25ga=596b281b34b5ab1d3849c66b978d176b
             x509-1.7.3-30RX2XeTxE9KNrE2njE3sg=12355c224cddca01537d816be2c864a3
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=2d4c17574909e037fa0256847c747647
haddock-interfaces: /usr/share/doc/haskell-jose/html/jose.haddock
haddock-html: /usr/share/doc/haskell-jose/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
